@@ -6,7 +6,7 @@ from databases import Database
 from muffin.plugin import BasePlugin
 
 
-__version__ = "0.2.3"
+__version__ = "0.2.4"
 __project__ = "muffin-databases"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "MIT"
@@ -38,4 +38,7 @@ class Plugin(BasePlugin):
 
     def __getattr__(self, name) -> t.Any:
         """Proxy attributes to self database."""
+        if not self.installed:
+            raise AttributeError(name)
+
         return getattr(self.__database__, name)
